@@ -17,10 +17,10 @@ class Makecmd(object):
         parser = argparse.ArgumentParser(description='Converts Python scripts to callable shell commands',
                                          usage='''makecmd <command> [file] 
     
-        The most command commands used with makecmd are: 
+        The most common commands used with makecmd are: 
 
         convert     Converts Python file into shell executable
-        listcmds    Lists files converted by makecmd
+        list        Lists files converted by makecmd
         delete      Deletes bash executables made by makecmd
         ''')
 
@@ -104,7 +104,7 @@ class Makecmd(object):
             file_storage.write(new_filename)
             file_storage.close()
 
-    def listcmds(self):
+    def list(self):
         parser = argparse.ArgumentParser(description="""
         Lists files converted by bashify """)
         args = parser.parse_args(sys.argv[2:])
@@ -120,7 +120,8 @@ class Makecmd(object):
                                          )
         parser.add_argument("file", type=str, help="Name of bash executable")
         args = parser.parse_args(sys.argv[2:])
-
+        if ("Linux" in self.os):
+            self.exec_directory = "/usr/bin"
         FILE = args.file
         try:
             os.system(f"rm -rf {self.exec_directory}/{FILE}")
